<?php

/**
 * 
 * @link              https://competition.demo.getfoundni.co.uk/
 * @since             1.0.0
 * @package           Gfni_Spot_The_Ball_Addon
 *
 * @wordpress-plugin
 * Plugin Name:       GFNI - Spot The Ball Addon
 * Plugin URI:        gfni-spot-the-ball-addon
 * Description:       Adds Spot The Ball options to your competition website.
 * Version:           1.0.0
 * Author:            Get Found NI
 * Author URI:        https://competition.demo.getfoundni.co.uk/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       gfni-spot-the-ball-addon
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'GFNI_SPOT_THE_BALL_ADDON_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-gfni-spot-the-ball-addon-activator.php
 */
function activate_gfni_spot_the_ball_addon() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-gfni-spot-the-ball-addon-activator.php';
	Gfni_Spot_The_Ball_Addon_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-gfni-spot-the-ball-addon-deactivator.php
 */
function deactivate_gfni_spot_the_ball_addon() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-gfni-spot-the-ball-addon-deactivator.php';
	Gfni_Spot_The_Ball_Addon_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_gfni_spot_the_ball_addon' );
register_deactivation_hook( __FILE__, 'deactivate_gfni_spot_the_ball_addon' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-gfni-spot-the-ball-addon.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_gfni_spot_the_ball_addon() {

	// Verify if Advanced Custom Fields PRO is activated
	add_action('admin_init', function() {
		if (is_admin() && current_user_can('activate_plugins') && (!class_exists('ACF') || !class_exists('Wc_Lottery_Pn'))) {
			add_action('admin_notices', function() {
				$notice = 'Spot the ball Plugin requires that ACF & Raffle Plugins are installed and active. Please see details on the product page: <a href="https://services.getfoundni.co.uk/shop/plugin/spot-the-ball-addon/">https://services.getfoundni.co.uk/shop/plugin/spot-the-ball-addon/</a>';
				echo "<div class='error'><p>$notice</p></div>";
			});
			deactivate_plugins(plugin_basename(__FILE__));
			if (isset($_GET['activate'])) {
				unset($_GET['activate']);
			}
		}
	});

	$plugin = new Gfni_Spot_The_Ball_Addon();
	$plugin->run();

}
run_gfni_spot_the_ball_addon();
